pub struct FrameReader { /* private fields */ }Expand description
State for reading Perfetto IPC frames.
Each frame is composed of a 32 bit length in little endian, followed by the proto-encoded message. This state handles reads that only include partial messages.
Implementations
Sourceimpl FrameReader
impl FrameReader
pub fn new(file: FileHandle) -> Self
Sourcepub fn next_frame_blocking<L>(
&mut self,
locked: &mut Locked<L>,
current_task: &CurrentTask,
) -> Result<IpcFrame, IpcReadError>where
L: LockEqualOrBefore<FileOpsCore>,
pub fn next_frame_blocking<L>(
&mut self,
locked: &mut Locked<L>,
current_task: &CurrentTask,
) -> Result<IpcFrame, IpcReadError>where
L: LockEqualOrBefore<FileOpsCore>,
Repeatedly reads from the specified file until a full message is available.