pub struct Producer { /* private fields */ }Implementations
Sourceimpl Producer
impl Producer
Sourcepub fn new(
current_task: &CurrentTask,
socket: FileHandle,
) -> Result<Self, ProducerError>
pub fn new( current_task: &CurrentTask, socket: FileHandle, ) -> Result<Self, ProducerError>
Opens a socket connection to the specified socket path and initializes the requisite bookkeeping information.
Sourcepub fn initialize_connection(
&mut self,
request: InitializeConnectionRequest,
current_task: &CurrentTask,
) -> Result<InitializeConnectionResponse, ProducerError>
pub fn initialize_connection( &mut self, request: InitializeConnectionRequest, current_task: &CurrentTask, ) -> Result<InitializeConnectionResponse, ProducerError>
Called once only after establishing the connection with the Service. The service replies sending the shared memory file descriptor in reply.
Sourcepub fn register_data_source(
&mut self,
request: RegisterDataSourceRequest,
current_task: &CurrentTask,
) -> Result<RegisterDataSourceResponse, ProducerError>
pub fn register_data_source( &mut self, request: RegisterDataSourceRequest, current_task: &CurrentTask, ) -> Result<RegisterDataSourceResponse, ProducerError>
Advertises a new data source.
Sourcepub fn get_command_request(
&mut self,
current_task: &CurrentTask,
) -> Result<(), ProducerError>
pub fn get_command_request( &mut self, current_task: &CurrentTask, ) -> Result<(), ProducerError>
This is a backchannel to get asynchronous commands / notifications back from the Service.
Sourcepub fn get_command_response(
&mut self,
current_task: &CurrentTask,
) -> Result<(Option<GetAsyncCommandResponse>, bool), ProducerError>
pub fn get_command_response( &mut self, current_task: &CurrentTask, ) -> Result<(Option<GetAsyncCommandResponse>, bool), ProducerError>
After calling get_command_request, block until a response can be read.