pub struct Producer { /* private fields */ }Implementations
Sourceimpl Producer
impl Producer
Sourcepub fn new<L>(
locked: &mut Locked<L>,
current_task: &CurrentTask,
socket: FileHandle,
) -> Result<Self, ProducerError>where
L: LockEqualOrBefore<FileOpsCore>,
pub fn new<L>(
locked: &mut Locked<L>,
current_task: &CurrentTask,
socket: FileHandle,
) -> Result<Self, ProducerError>where
L: LockEqualOrBefore<FileOpsCore>,
Opens a socket connection to the specified socket path and initializes the requisite bookkeeping information.
Sourcepub fn initialize_connection<L>(
&mut self,
request: InitializeConnectionRequest,
locked: &mut Locked<L>,
current_task: &CurrentTask,
) -> Result<InitializeConnectionResponse, ProducerError>where
L: LockEqualOrBefore<FileOpsCore>,
pub fn initialize_connection<L>(
&mut self,
request: InitializeConnectionRequest,
locked: &mut Locked<L>,
current_task: &CurrentTask,
) -> Result<InitializeConnectionResponse, ProducerError>where
L: LockEqualOrBefore<FileOpsCore>,
Called once only after establishing the connection with the Service. The service replies sending the shared memory file descriptor in reply.
Sourcepub fn register_data_source<L>(
&mut self,
request: RegisterDataSourceRequest,
locked: &mut Locked<L>,
current_task: &CurrentTask,
) -> Result<RegisterDataSourceResponse, ProducerError>where
L: LockEqualOrBefore<FileOpsCore>,
pub fn register_data_source<L>(
&mut self,
request: RegisterDataSourceRequest,
locked: &mut Locked<L>,
current_task: &CurrentTask,
) -> Result<RegisterDataSourceResponse, ProducerError>where
L: LockEqualOrBefore<FileOpsCore>,
Advertises a new data source.
Sourcepub fn get_command_request<L>(
&mut self,
locked: &mut Locked<L>,
current_task: &CurrentTask,
) -> Result<(), ProducerError>where
L: LockEqualOrBefore<FileOpsCore>,
pub fn get_command_request<L>(
&mut self,
locked: &mut Locked<L>,
current_task: &CurrentTask,
) -> Result<(), ProducerError>where
L: LockEqualOrBefore<FileOpsCore>,
This is a backchannel to get asynchronous commands / notifications back from the Service.
Sourcepub fn get_command_response<L>(
&mut self,
locked: &mut Locked<L>,
current_task: &CurrentTask,
) -> Result<(Option<GetAsyncCommandResponse>, bool), ProducerError>where
L: LockEqualOrBefore<FileOpsCore>,
pub fn get_command_response<L>(
&mut self,
locked: &mut Locked<L>,
current_task: &CurrentTask,
) -> Result<(Option<GetAsyncCommandResponse>, bool), ProducerError>where
L: LockEqualOrBefore<FileOpsCore>,
After calling get_command_request, block until a response can be read.